module Werd
  class ProjectWordCounter
    include Contracts
    attr_reader :project_id, :token

    Contract String, String => Any
    def initialize token, project_id
      @token, @project_id = token, project_id
    end

    Contract None => WordList
    def words
      counts = Hash.new 0
      document.split(/\W/).select do |str|
        str.size > 0
      end.map do |chunk|
        chunk.downcase
      end.each do |word|
        counts[word] += 1
      end
      counts.to_a.sort_by(&:last).reverse
    end

    Contract None => RespondTo[:project]
    def client
      @client ||= TrackerApi::Client.new(token: token)
    end

    Contract None => Any
    def project
      client.project project_id
    end

    Contract None => String
    def document
      project.stories.map do |s|
        [s.name, s.description]
      end.flatten.join("\n")
    end
  end
end
